@@ -19,14 +19,14 @@ public:
         m_ButtonReplay = new BTReplay();
         m_scene = new QGraphicsScene(0, 0, widgetWidth, widgetHeight - 50);
         m_scene->addItem(m_ButtonReplay);
-        qInfo() << "SetUp" << endl;
+        qInfo() << "SetUp" << Qt::endl;
     }
     void TearDown() //TEST跑完之后会执行TearDown
     {
         m_scene->removeItem(m_ButtonReplay);
         delete m_ButtonReplay;
         delete m_scene;
-        qInfo() << "TearDown" << endl;
+        qInfo() << "TearDown" << Qt::endl;
     }
     BTReplay *m_ButtonReplay;
     QGraphicsScene *m_scene;
